@@ -1,5 +1,5 @@
 package App::week;
-our $VERSION = "1.03";
+our $VERSION = "1.0301";
 
 use v5.14;
 use warnings;
@@ -42,11 +42,11 @@ my %DEFAULT_COLORMAP = (
 
 use Getopt::EX::Hashed; {
 
-    Getopt::EX::Hashed->configure(DEFAULT => [ is => 'ro' ]);
+    Getopt::EX::Hashed->configure(DEFAULT => [ is => 'rw' ]);
 
     has ARGV     => default => [];
-    has COLORMAP => is => 'rw';
-    has CM       => is => 'rw';
+    has COLORMAP => ;
+    has CM       => ;
 
     my($sec, $min, $hour, $mday, $mon, $year) = CORE::localtime(time);
     has year => default => $year + 1900;
@@ -76,11 +76,19 @@ use Getopt::EX::Hashed; {
     has weeknumber  => ' W :1     ' ;
 
     has '+center' => sub {
-	$_->{after} = $_->{before} = $_[1];
+	$_->after = $_->before = $_[1];
     };
 
     has '+weeknumber' => sub {
-	${$_->config}{weeknumber} = $_[1];
+	${$_->config}{$_[0]} = $_[1];
+    };
+
+    has '+rgb24' => sub {
+	$Getopt::EX::Colormap::RGB24 = !!$_[1];
+    };
+
+    has '+config' => sub {
+	App::week::CalYear::Configure $_[1] => $_[2];
     };
 
     has '+help' => sub {
@@ -94,18 +102,17 @@ use Getopt::EX::Hashed; {
 	exit;
     };
 
-    has "<>" =>
-	sub {
-	    my $obj = $_;
-	    local $_ = $_[0];
-	    if (/^-+([0-9]+)$/) {
-		$obj->{months} = $1;
-	    } elsif (/^-/) {
-		die "$_: Unknown option\n";
-	    } else {
-		push @{$obj->ARGV}, $_;
-	    }
-	};
+    has "<>" => sub {
+	my $obj = $_;
+	local $_ = $_[0];
+	if (/^-+([0-9]+)$/) {
+	    $obj->months = $1;
+	} elsif (/^-/) {
+	    die "$_: Option error\n";
+	} else {
+	    push @{$obj->ARGV}, $_;
+	}
+    };
 
 } no Getopt::EX::Hashed;
 
@@ -168,19 +175,8 @@ sub deal_option {
 	exit;
     }
 
-    # --rgb24
-    if (defined $app->rgb24) {
-	no warnings 'once';
-	$Getopt::EX::Colormap::RGB24 = $app->rgb24;
-    }
-
-    # --config
-    if (%{$app->config}) {
-	App::week::CalYear::Configure %{$app->config};
-    }
-
     # -p, -P
-    $app->{year_on} //= $app->mon if $app->mday;
+    $app->year_on //= $app->mon if $app->mday;
     if ($app->year_on_all) {
 	App::week::CalYear::Configure show_year => [ 1..12 ];
     }
@@ -195,7 +191,7 @@ sub deal_option {
     }
 
     # -y, -Y
-    $app->{years} //= 1 if $app->show_year;
+    $app->years //= 1 if $app->show_year;
 
     return $app;
 }
@@ -298,7 +294,7 @@ sub cell {
     my @cal = @{$calyear[$y][$m]};
 
     # XXX this is not the best place to initialize...
-    $obj->{cell_width} //= length $cal[2];
+    $obj->cell_width //= length $cal[2];
 
     my %label;
     @label{qw(month week days)} = $d
@@ -347,7 +343,7 @@ B<week> [ -MI<module> ] [ option ] [ date ]
 
 =head1 VERSION
 
-Version 1.03
+Version 1.0301
 
 =head1 DESCRIPTION
 
